@@ -317,6 +317,8 @@
 stat_fit_tb <- function(mapping = NULL,
                         data = NULL,
                         geom = "table_npc",
+                        position = "identity",
+                        ...,
                         method = "lm",
                         method.args = list(formula = y ~ x),
                         n.min = 2L,
@@ -328,7 +330,6 @@ stat_fit_tb <- function(mapping = NULL,
                         p.digits = digits,
                         label.x = "center",
                         label.y = "top",
-                        position = "identity",
                         table.theme = NULL,
                         table.rownames = FALSE,
                         table.colnames = TRUE,
@@ -336,8 +337,7 @@ stat_fit_tb <- function(mapping = NULL,
                         parse = FALSE,
                         na.rm = FALSE,
                         show.legend = FALSE,
-                        inherit.aes = TRUE,
-                        ...) {
+                        inherit.aes = TRUE) {
   ggplot2::layer(
     stat = StatFitTb, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
