@@ -103,22 +103,26 @@
 #' @examples
 #' # package 'broom' needs to be installed to run these examples
 #'
-#' if (requireNamespace("broom", quietly = TRUE)) {
-#'   broom.installed <- TRUE
+#' broom.installed <- requireNamespace("broom", quietly = TRUE)
+#' gginnards.installed <- requireNamespace("gginnards", quietly = TRUE)
+#'
+#' if (broom.installed) {
 #'   library(broom)
 #'   library(quantreg)
+#' }
+#'
+#' if (gginnards.installed) {
+#'     library(gginnards)
+#' }
 #'
 #' # Inspecting the returned data using geom_debug()
-#'   if (requireNamespace("gginnards", quietly = TRUE)) {
-#'     library(gginnards)
-#'
+#'   if (broom.installed && gginnards.installed) {
 #'     ggplot(mtcars, aes(x = disp, y = mpg)) +
 #'       stat_smooth(method = "lm") +
 #'       geom_point(aes(colour = factor(cyl))) +
 #'       stat_fit_glance(method = "lm",
 #'                       method.args = list(formula = y ~ x),
 #'                       geom = "debug")
-#'   }
 #' }
 #'
 #' if (broom.installed)
@@ -192,6 +196,8 @@
 stat_fit_glance <- function(mapping = NULL,
                             data = NULL,
                             geom = "text_npc",
+                            position = "identity",
+                            ...,
                             method = "lm",
                             method.args = list(formula = y ~ x),
                             n.min = 2L,
@@ -200,9 +206,9 @@ stat_fit_glance <- function(mapping = NULL,
                             label.y = "top",
                             hstep = 0,
                             vstep = 0.075,
-                            position = "identity",
-                            na.rm = FALSE, show.legend = FALSE,
-                            inherit.aes = TRUE, ...) {
+                            na.rm = FALSE,
+                            show.legend = FALSE,
+                            inherit.aes = TRUE) {
   ggplot2::layer(
     stat = StatFitGlance, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
@@ -479,7 +485,8 @@ StatFitGlance <-
 #'   passed to [generics::augment()] whether they are silently ignored or obeyed
 #'   depends on each specialization of [augment()], so do carefully read the
 #'   documentation for the version of [augment()] corresponding to the `method`
-#'   used to fit the model.
+#'   used to fit the model. Be aware that `se_fit = FALSE` is the default in
+#'   these methods even when supported.
 #'
 #' @family ggplot statistics for model fits
 #'
@@ -492,23 +499,27 @@ StatFitGlance <-
 #' # Package 'broom' needs to be installed to run these examples.
 #' # We check availability before running them to avoid errors.
 #'
-#' if (requireNamespace("broom", quietly = TRUE)) {
-#'   broom.installed <- TRUE
+#' broom.installed <- requireNamespace("broom", quietly = TRUE)
+#' gginnards.installed <- requireNamespace("gginnards", quietly = TRUE)
+#'
+#' if (broom.installed) {
 #'   library(broom)
 #'   library(quantreg)
+#' }
 #'
 #' # Inspecting the returned data using geom_debug()
-#'   if (requireNamespace("gginnards", quietly = TRUE)) {
+#'   if (gginnards.installed) {
 #'     library(gginnards)
+#' }
 #'
 #' # Regression by panel, inspecting data
+#' if (broom.installed & gginnards.installed) {
 #'     ggplot(mtcars, aes(x = disp, y = mpg)) +
 #'       geom_point(aes(colour = factor(cyl))) +
 #'       stat_fit_augment(method = "lm",
 #'                        method.args = list(formula = y ~ x),
 #'                        geom = "debug",
 #'                        summary.fun = colnames)
-#'   }
 #' }
 #'
 #' # Regression by panel example
@@ -518,6 +529,13 @@ StatFitGlance <-
 #'     stat_fit_augment(method = "lm",
 #'                      method.args = list(formula = y ~ x))
 #'
+#' if (broom.installed)
+#'   ggplot(mtcars, aes(x = disp, y = mpg)) +
+#'     geom_point(aes(colour = factor(cyl))) +
+#'     stat_fit_augment(method = "lm",
+#'                      augment.args = list(se_fit = TRUE),
+#'                      method.args = list(formula = y ~ x + I(x^2)))
+#'
 #' # Residuals from regression by panel example
 #' if (broom.installed)
 #'   ggplot(mtcars, aes(x = disp, y = mpg)) +
@@ -532,6 +550,7 @@ StatFitGlance <-
 #'   ggplot(mtcars, aes(x = disp, y = mpg, colour = factor(cyl))) +
 #'     geom_point() +
 #'     stat_fit_augment(method = "lm",
+#'                      augment.args = list(se_fit = TRUE),
 #'                      method.args = list(formula = y ~ x))
 #'
 #' # Residuals from regression by group example
@@ -566,16 +585,20 @@ StatFitGlance <-
 #'     stat_fit_augment(method = "rq")
 #'
 #'
-stat_fit_augment <- function(mapping = NULL, data = NULL, geom = "smooth",
+stat_fit_augment <- function(mapping = NULL,
+                             data = NULL,
+                             geom = "smooth",
+                             position = "identity",
+                             ...,
                              method = "lm",
                              method.args = list(formula = y ~ x),
                              n.min = 2L,
                              augment.args = list(),
                              level = 0.95,
                              y.out = ".fitted",
-                             position = "identity",
-                             na.rm = FALSE, show.legend = FALSE,
-                             inherit.aes = TRUE, ...) {
+                             na.rm = FALSE,
+                             show.legend = FALSE,
+                             inherit.aes = TRUE) {
   ggplot2::layer(
     stat = StatFitAugment, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
@@ -599,14 +622,14 @@ stat_fit_augment <- function(mapping = NULL, data = NULL, geom = "smooth",
 #' @usage NULL
 #'
 fit_augment_compute_group_fun <- function(data,
-                                    scales,
-                                    method,
-                                    method.args,
-                                    n.min,
-                                    augment.args,
-                                    level,
-                                    y.out,
-                                    ...) {
+                                          scales,
+                                          method,
+                                          method.args,
+                                          n.min,
+                                          augment.args,
+                                          level,
+                                          y.out,
+                                          ...) {
   unAsIs <- function(X) {
     if ("AsIs" %in% class(X)) {
       class(X) <- class(X)[-match("AsIs", class(X))]
@@ -662,7 +685,8 @@ fit_augment_compute_group_fun <- function(data,
     z[["t.value"]] <- rep_len(NA_real_, nrow(z))
   }
   if (!exists(".se.fit", z)) {
-    z[[".se.fit"]] <- rep_len(NA_real_, nrow(z))
+#    z[[".se.fit"]] <- rep_len(NA_real_, nrow(z)) # triggered warning!
+    z[[".se.fit"]] <- rep_len(0, nrow(z))
   }
   z[["fm.class"]] <- rep_len(fm.class[1], nrow(z))
   z[["fm.method"]] <- rep_len(method.name, nrow(z))
@@ -804,19 +828,21 @@ StatFitAugment <-
 #' # Package 'broom' needs to be installed to run these examples.
 #' # We check availability before running them to avoid errors.
 #'
-#' if (requireNamespace("broom", quietly = TRUE)) {
-#'   broom.installed <- TRUE
+#' broom.installed <- requireNamespace("broom", quietly = TRUE)
+#' gginnards.installed <- requireNamespace("gginnards", quietly = TRUE)
+#'
+#' if (broom.installed) {
 #'   library(broom)
 #'   library(quantreg)
+#' }
 #'
 #' # Inspecting the returned data using geom_debug()
-#'   if (requireNamespace("gginnards", quietly = TRUE)) {
+#'   if (gginnards.installed) {
 #'     library(gginnards)
+#' }
 #'
-#' # This provides a quick way of finding out the names of the variables that
-#' # are available for mapping to aesthetics. This is specially important for
-#' # this stat as these names depend on the specific tidy() method used, which
-#' # depends on the method used, such as lm(), used to fit the model.
+#' # Regression by panel, inspecting data
+#' if (broom.installed && gginnards.installed) {
 #'
 #' # Regression by panel, default column names
 #'   ggplot(mtcars, aes(x = disp, y = mpg)) +
@@ -833,7 +859,6 @@ StatFitAugment <-
 #'     stat_fit_tidy(method = "lm",
 #'                   method.args = list(formula = y ~ x + I(x^2)),
 #'                   geom = "debug", sanitize.names = TRUE)
-#'   }
 #' }
 #'
 #' # Regression by panel example
@@ -885,18 +910,23 @@ StatFitAugment <-
 #'                                                 after_stat(x_estimate),
 #'                                                 after_stat(x_p.value))))
 #'
-stat_fit_tidy <- function(mapping = NULL, data = NULL, geom = "text_npc",
+stat_fit_tidy <- function(mapping = NULL,
+                          data = NULL,
+                          geom = "text_npc",
+                          position = "identity",
+                          ...,
                           method = "lm",
                           method.args = list(formula = y ~ x),
                           n.min = 2L,
                           tidy.args = list(),
-                          label.x = "left", label.y = "top",
+                          label.x = "left",
+                          label.y = "top",
                           hstep = 0,
                           vstep = NULL,
                           sanitize.names = FALSE,
-                          position = "identity",
-                          na.rm = FALSE, show.legend = FALSE,
-                          inherit.aes = TRUE, ...) {
+                          na.rm = FALSE,
+                          show.legend = FALSE,
+                          inherit.aes = TRUE) {
   ggplot2::layer(
     stat = StatFitTidy, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
