@@ -305,7 +305,8 @@
 #'
 #' @export
 #'
-stat_ma_eq <- function(mapping = NULL, data = NULL,
+stat_ma_eq <- function(mapping = NULL,
+                       data = NULL,
                        geom = "text_npc",
                        position = "identity",
                        ...,
