@@ -15,7 +15,7 @@
 #'
 #'   As the fitted line is the same whether \code{x} or \code{y} is on the rhs
 #'   of the model equation, \code{orientation} even if accepted does not have an
-#'   effect on the fit. In contrast, \code{\link[ggplot2]{geom_smooth}} treats
+#'   effect on the fitted line. In contrast, \code{\link[ggplot2]{geom_smooth}} treats
 #'   each axis differently and can thus have two orientations. The orientation
 #'   is easy to deduce from the argument passed to \code{formula}. Thus,
 #'   \code{stat_ma_line()} will by default guess which orientation the layer
@@ -273,8 +273,9 @@ stat_ma_line <- function(mapping = NULL,
 #' @usage NULL
 #'
 ma_line_compute_group_fun <-
-  function(data, scales,
-           method = NULL,
+  function(data,
+           scales,
+           method,
            method.args = list(),
            n.min = 2L,
            formula = NULL,
@@ -378,7 +379,9 @@ ma_line_compute_group_fun <-
       }
     })
 
-    if (!inherits(fm, "lmodel2")) {
+    if (!length(fm) || (is.atomic(fm) && is.na(fm))) {
+      return(data.frame())
+    } else if (!inherits(fm, "lmodel2")) {
       stop("Method \"", method.name, "\" did not return a \"lmodel2\" object")
     }
 
