@@ -436,30 +436,31 @@
 #'
 #' @export
 #'
-stat_quant_eq <- function(mapping = NULL, data = NULL,
-                         geom = "text_npc",
-                         position = "identity",
-                         ...,
-                         formula = NULL,
-                         quantiles = c(0.25, 0.5, 0.75),
-                         method = "rq:br",
-                         method.args = list(),
-                         n.min = 3L,
-                         eq.with.lhs = TRUE,
-                         eq.x.rhs = NULL,
-                         coef.digits = 3,
-                         coef.keep.zeros = TRUE,
-                         decreasing = getOption("ggpmisc.decreasing.poly.eq", FALSE),
-                         rho.digits = 4,
-                         label.x = "left", label.y = "top",
-                         hstep = 0,
-                         vstep = NULL,
-                         output.type = NULL,
-                         na.rm = FALSE,
-                         orientation = NA,
-                         parse = NULL,
-                         show.legend = FALSE,
-                         inherit.aes = TRUE) {
+stat_quant_eq <- function(mapping = NULL,
+                          data = NULL,
+                          geom = "text_npc",
+                          position = "identity",
+                          ...,
+                          formula = NULL,
+                          quantiles = c(0.25, 0.5, 0.75),
+                          method = "rq:br",
+                          method.args = list(),
+                          n.min = 3L,
+                          eq.with.lhs = TRUE,
+                          eq.x.rhs = NULL,
+                          coef.digits = 3,
+                          coef.keep.zeros = TRUE,
+                          decreasing = getOption("ggpmisc.decreasing.poly.eq", FALSE),
+                          rho.digits = 4,
+                          label.x = "left", label.y = "top",
+                          hstep = 0,
+                          vstep = NULL,
+                          output.type = NULL,
+                          na.rm = FALSE,
+                          orientation = NA,
+                          parse = NULL,
+                          show.legend = FALSE,
+                          inherit.aes = TRUE) {
   # we guess formula from orientation
   if (is.null(formula)) {
     if (is.na(orientation) || orientation == "x") {
